create_subagent_worktree

Function create_subagent_worktree 

pub fn create_subagent_worktree(
    parent_cwd: &Path,
    agent_id: &str,
) -> Result<WorktreeInfo, AgentError>
Create or resume a git worktree for a subagent.

Creates the worktree at <git_root>/.worktrees/subagents/<agent_id>. If a worktree already exists at that path, it is resumed (fast path). Uses a detached HEAD for simplicity.