AskUserQuestionTool

Struct AskUserQuestionTool 

pub struct AskUserQuestionTool;
Tool that presents structured questions to the user.

This tool returns a questions_ready signal with the questions for the host application to present. The host is responsible for collecting answers and feeding them back in the next turn.