pub enum ToolExecutionEvent {
ToolStarted {
tool_call_id: String,
name: String,
detail: String,
},
ToolProgress {
tool_call_id: Option<String>,
name: String,
message: String,
data: Option<Value>,
},
ApprovalRequested {
tool_call_id: String,
name: String,
reason: String,
},
ApprovalResolved {
tool_call_id: String,
name: String,
decision: String,
},
PolicyStarted {
point: String,
name: String,
},
PolicyCompleted {
point: String,
name: String,
feedback_count: usize,
},
}Expand description
Lifecycle event emitted by the executor for one tool invocation.
Variants
ToolStarted
Emitted once when the tool starts (after permission, before invoke).
ToolProgress
Streaming progress update from inside the tool.
ApprovalRequested
A tool call has been suspended pending human approval.
ApprovalResolved
Human approval has been resolved for a suspended tool call.
PolicyStarted
PolicyCompleted