pub fn platform_base_env() -> HashMap<String, String>
Return the small set of host environment variables needed for tools to launch platform-native child processes without inheriting the full process environment.